@@ -17,11 +17,12 @@ import json
 from oslo_log import log
 from osprofiler import profiler
 
-from vitrage.api_handler.apis.base import EntityGraphApisBase
+from vitrage.api_handler.apis import base
 from vitrage.common.constants import EntityCategory as ECategory
 from vitrage.common.constants import HistoryProps as HProps
 from vitrage.common.constants import TenantProps
 from vitrage.common.constants import VertexProperties as VProps
+from vitrage.common.utils import compress_obj
 from vitrage.datasources.alarm_properties import AlarmProperties as AProps
 from vitrage.entity_graph.mappings.operational_alarm_severity import \
     OperationalAlarmSeverity
@@ -32,13 +33,9 @@ LOG = log.getLogger(__name__)
 
 @profiler.trace_cls("alarm apis",
                     info={}, hide_args=False, trace_private=False)
-class AlarmApis(EntityGraphApisBase):
-
-    def __init__(self, entity_graph, conf, db):
-        self.entity_graph = entity_graph
-        self.conf = conf
-        self.db = db
+class AlarmApis(base.EntityGraphApisBase):
 
+    @base.lock_graph
     def get_alarms(self, ctx, vitrage_id, all_tenants, *args, **kwargs):
 
         kwargs = self._parse_kwargs(kwargs)
@@ -46,7 +43,7 @@ class AlarmApis(EntityGraphApisBase):
         if not vitrage_id or vitrage_id == 'all':
             if not all_tenants:
                 kwargs['project_id'] = \
-                    ctx.get(TenantProps.TENANT, 'no-project')
+                    ctx.get(TenantProps.PROJECT_ID, 'no-project')
                 kwargs['is_admin_project'] = \
                     ctx.get(TenantProps.IS_ADMIN, False)
         else:
@@ -54,9 +51,11 @@ class AlarmApis(EntityGraphApisBase):
             kwargs.get('filter_vals', []).append(vitrage_id)
 
         alarms = self._get_alarms(*args, **kwargs)
-        return json.dumps({'alarms': [v.payload for v in alarms]})
+        data = {'alarms': [v.payload for v in alarms]}
+        return compress_obj(data, level=1)
 
     # TODO(annarez): add db support
+    @base.lock_graph
     def show_alarm(self, ctx, vitrage_id):
         LOG.debug('Show alarm with vitrage_id: %s', vitrage_id)
 
@@ -66,7 +65,7 @@ class AlarmApis(EntityGraphApisBase):
             return None
 
         is_admin = ctx.get(TenantProps.IS_ADMIN, False)
-        curr_project = ctx.get(TenantProps.TENANT, None)
+        curr_project = ctx.get(TenantProps.PROJECT_ID, None)
         alarm_project = alarm.get(VProps.PROJECT_ID)
         if not is_admin and curr_project != alarm_project:
             LOG.warning('Alarm show - Authorization failed (%s)', vitrage_id)
@@ -74,10 +73,11 @@ class AlarmApis(EntityGraphApisBase):
 
         return json.dumps(alarm.properties)
 
+    @base.lock_graph
     def get_alarm_counts(self, ctx, all_tenants):
         LOG.debug("AlarmApis get_alarm_counts - all_tenants=%s", all_tenants)
 
-        project_id = ctx.get(TenantProps.TENANT, None)
+        project_id = ctx.get(TenantProps.PROJECT_ID, None)
         is_admin_project = ctx.get(TenantProps.IS_ADMIN, False)
 
         if all_tenants:
